==> focustuner-0.1.4.tar.gz: focustuner-0.1.4/README.md <==
# Load Tuner Library #

This is a locally installable verion of the python Focus Load Tuner Library

### Version History ###

0.1.1: Updated README and Authors

0.1.0 : Initial Build. 

### Acknowledgements ###

A special thanks to Devon Donahue and Scott Schafer for the initial version of this code written in socket commands.

## Additional Editing and Build instructions ##

Activate the virtual environment using:

```
. venv/activate/bin
```

You need to have the project packaged to be able to run it in a test mode. the commands are:

python3 -m pip install build
python3 -m build --wheel
pip3 install dist/loadtuner-0.1.0-py3-none-any.whl

and using:

```
python3 -m unittest discover
```

to test the code

### Library Creation ###
This library was created using instructions form https://medium.com/analytics-vidhya/how-to-create-a-python-library-7d5aea80cc3f
Frankly it was started more than once so there is a high probability there are unnecessary components. It was a valiant effort though. 

try number 2
https://medium.com/@tushar_datascience/creating-a-python-library-a-step-by-step-guide-with-a-simple-example-c87b653b9a4e

```
python -m build
twine upload dist/* --repository-url https://upload.pypi.org/legacy/
```

Ensure you update the version number and delete previous tar.gz and whl files for the previous version. This seems to do it.

### Start virtual environment ###

```
python -m venv venv
```

Activate for windows:

```
. venv\Scripts\activate
```

Activate for Mac:

```
. venv/bin/activate
```

==> focustuner-0.2.0.tar.gz: focustuner-0.2.0/README.md <==
# Load Tuner Library #

This is a locally installable verion of the python Focus Load Tuner Library

### Version History ###

0.1.1: Updated README and Authors

0.1.0 : Initial Build. 

### Acknowledgements ###

A special thanks to Devon Donahue and Scott Schafer for the initial version of this code written in socket commands.

## Additional Editing and Build instructions ##

You need to have the project packaged to be able to run it in a test mode. the commands are:

python3 -m pip install build
python3 -m build --wheel
pip3 install dist/focustuner-0.1.0-py3-none-any.whl

python -m pip install build
python -m build --wheel
pip install dist/focustuner-0.1.0-py3-none-any.whl

and using:

```
python3 -m unittest discover
python -m unittest discover
```

python -m unittest discover

to test the code

### Library Creation ###
This library was created using instructions form https://medium.com/analytics-vidhya/how-to-create-a-python-library-7d5aea80cc3f
Frankly it was started more than once so there is a high probability there are unnecessary components. It was a valiant effort though. 

try number 2
https://medium.com/@tushar_datascience/creating-a-python-library-a-step-by-step-guide-with-a-simple-example-c87b653b9a4e

```
python -m build
twine upload dist/* --repository-url https://upload.pypi.org/legacy/
```

Ensure you update the version number and delete previous tar.gz and whl files for the previous version. This seems to do it.

### Start virtual environment ###

```
python -m venv venv
```

Activate for windows:

```
. venv\Scripts\activate
```

Activate for Mac:

```
. venv/bin/activate
```
